bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 5. Aventiure
___________________________________________________ #### Aventivre wie sivrit #### chriemhilt alreste ersach
###### 265 | ### Man sach si taegelichen | nv riten an den rin ### die cer hohgecite | gerne wolden sin ### di dvrch des kvneges liebe | chomn in daz lant ### den bot man svemelichen | ross vnt herlich gewant
###### 266 | ### in was ir gesidele | allen wol bereit ### den hoehsten vnt den besten | als vns daz ist geseit ### zwein vnt drizech fvrsten | da cer hohgecit ### da cierten sich engegene | di scoenen frovwen wider strit
###### 267 | ### ez was da vil vnmvezech | giselher daz chint ### di geste mit den chvnden | vil gvetelich sint ### di enpfieng er vnd gernot | vnt ovch ir beider man ### ia grvozten si di degene | als ez nach ern was getan
###### 268 | ### vil goltroter saetele | si fvorten in daz lant ### zierliche scilde | vnt herlich gewant ### brahten si ze rine | zvo der hohgecit ### manegen vngesvnden | sah man vroelichen sit
###### 269 | ### die in den betten lagen | vnt heten wunden not ### di mvosen des vergezzen | wi herte was der tot ### di siechen vngesvnden | mvosen si verchlagn ### si vrevten sich der maere | gein der hohgecite tagn
###### 270 | ### wie si lebn wolden | da cer wirtscaft ### wunne ane maze | mit vrevden vberchraft ### heten al die livte | swaz man ir da vant ### des hvop sich michel vrevde | vber al daz gvnthers lant
###### 271 | ### an einem pfinxtmorgen | sah man fvere gan ### gechleidet wunnechliche | vil manegen chvenen man ### fvnf tvsent oder mere | da cer hohgecit ### sich hvop div chvrcewile | an manegem ende wider strit
###### 272 | ### der wirt der hete di sinne | im was daz wol erchant ### wi rehte hercenliche | der helt von niderlant ### sine swester trvote | swi er si niene gesach ### der man so grozer scoene | vor allen ivnchfrovwen iach
###### 273 | ### do sprach zvo dem kvnege | der degen oertwin ### welt ir mit vollen eren | cer hohgecite sin ### so svlt ir lazen scovwen | div wunnechlichen kint ### di mit so grozen eren | hie cen bvrgonden sint
###### 274 | ### waz waere mannes wuenne | des vrevte sich sin lip ### ez en taeten scoene maegede | vnt herlichiv wip ### lazet iwer swester | fver iwer geste gan ### der rat der was ce liebe | manegem helde getan
###### 275 | ### des wil ich gerne volgen | sprach der kvnech do ### alle di ez erfvnden | di warens harte vro ### ernbot ez frovwen voten | vnt ir tohter wolgetan ### daz si mit ir mageden | hin ce hove solden gan
###### 276 | ### do wart vz den schrinen | gesvochet gvot gewant ### swaz man in der valde | der edelen waete vant ### di bovge mit den porten | des was in vil bereit ### sich cierte flizechliche | vil manech waetlichiv meit
###### 277 | ### vil manech reche tvmber | des tages hete mvot ### daz er an ce sehene | den frovwen waere gvot ### daz er dafver niht naeme | eins richen kvneges lant ### si sahen di vil gerne | di si nie heten bechant
###### 278 | ### do hiez der kvnec riche | mit siner swester gan ### di ir dienen solden | wol hvndert siner man ### ir vnt siner mage | di trvogen swert enhant ### daz was daz hovegesinde | von der bvrgonden lant
###### 279 | ### voten di vil richen | di sach man mit ir chomn ### div hete scoene vrovwen | gesellechlich genomn ### wol hvndert oder mere | di trvogen richiv chleit ### ovch gie danach ir tohter | vil manech waetlichiv meit
###### 280 | ### von einer chemenaten | sah man si alle gan ### do wart vil michel dringen | von heldn dar getan ### di des gedingen heten | ob chvnde daz gescehn ### daz si di maget edele | solden vroeliche sehn
###### 281 | ### nv gie div minnecliche | also der morgenrot ### tvot vz den trveben wolchen | da sciet von maneger not ### der si da trvog in hercen | vnt lange het getan ### er sach di minnechlichen | nv vil herlichen stan
###### 282 | ### ja lvhte ir von ir waete | vil manech edelstein ### ir rosenrotiv varwe | vil minnechlen scein ### ob iemem wunscen solde | der chvnde niht geiehn ### daz er ce dirre werelde | het iht scoeners gesehn
###### 283 | ### sam der liehte mane | vor den sternen stat ### der scin so lvoterliche | ab den wolchen gat ### dem stvont si nv geliche | vor maneger frovwen gvot ### des wart da wol gehoehet | den zieren helden der mvot
###### 284 | ### die richen chameraere | sah man vor ir gan ### di hohgemvoten degene | die ne wolden daz niht lan ### si ne drvngen da si sahen | die minechlichen meit ### sivride dem herrn | wart beide lieb vnd leit
###### 285 | ### er daht in sinem mvote | wi chvnde daz ergan ### daz ich dich minnen solde | daz ist ein tvmber wan ### sol aber ich dich vremeden | so waere ich sanfter tot ### er wart von den gedanchen | vil diche bleich vnd rot
###### 286 | ### do stvont so minnechliche | daz sigmvndes chint ### sam er entworfen waere | an ein permint ### von gvotes meisters listen | also man im iach ### daz man helt deheinen | nie so scoenen gesach
###### 287 | ### die mit den frovwen giengen | di hiezen von den wegen ### wichen allenthalben | daz leiste manech degen ### div hohe tragenden hercen | vrevten manegen lip ### man sach in hohen zvehten | manech herlichez wip
###### 288 | ### do sprach von bvrgonden | der herre gernot ### der iv sinen dienest | so gvetlichen bot ### gvnther vil lieber brvoder | dem svlt ir tvon alsam ### vor allen disen rechen | des rates ich nimmer mich gescam
###### 289 | ### ir heizet sivride | zvo miner swester chvmn ### daz in div maget grveze | des hab wir immer frvmn ### div nie gegrvezte rechen | div sol in grvezen pflegn ### damit wir habn gewunnen | den vil cierlichen degn
###### 290 | ### do giengens wirtes mage | da man den helt vant ### si sprachen zvo dem rechen | vzer niderlant ### iv hat der kvnech erlovbet | ir svlt ce hove gan ### sin swester sol ivch grvezen | daz ist cen eren iv getan
###### 291 | ### der herre in sinem mvote | was des vil gemeit ### do trvog er ime hercen | lieb ane leit ### daz er sehen solde | der scoenen voten kint ### mit minnechlichen tvgenden | si grvozte sivride sint
###### 292 | ### do si den hohgemvoten | vor ir stende sach ### do erzvnde sich sin varwe | div scoene magt sprach ### sit willechomn her sivrit | ein edel riter gvot ### do wart im von dem grvoze | vil wol gehoehet der mvot
###### 293 | ### er neig ir flizechliche | bi der hende si in vie ### wie rehte minnechliche | er bi der frovwen gie ### mit lieben ovgenblichen | einander sahen an ### der herre vnt ovch div frovwe | daz wart vil tovgenlich getan
###### 294 | ### wart iht da friwentliche | getwungen wiziv hant ### von hercenlieber minne | daz ist mir niht bechant ### doch en chan ich niht gelovbn | daz ez wurde lan ### si het im holden willen | chvnt vil sciere getan
###### 295 | ### bi der svmmer cite | vnt gein des meien tagn ### dorft er in sime hercen | nimmer mer getragn ### so vil der hohen vrevde | denn er da gewan ### do im div gie enhende | di er ce trvote wolde han
###### 296 | ### do gedahte manech reche | hey waer mir sam gescehen ### daz ich ir gienge nebene | sam ich in han gesehen ### oder bi ce ligene | daz liez ich ane haz ### ez en gediente noch nie reche | nach einer kvneginne baz
###### 297 | ### von swelher chvnege lande | di geste chomn dar ### di namen al geliche | niwan ir zweir war ### ir wart erlovbet chvssen | den waetlichen man ### im wart in al der werlde | nie so liebe getan
###### 298 | ### der kvnech von tenemarche | der sprach sa cestvnt ### diss vil hohen grvozes | lit maneger vngesvnt ### des ich vil wol enpfinde | von sivrides hant ### got en laz in nimmer mere | chomn in miniv kvnges lant
###### 299 | ### man hiez do allenthalben | wichen von den wegn ### der scoenen chrimhilde | manegen chvenen degn ### sah man gezogenliche | cer chirchen mit ir gan ### sit wart von ir gesceiden | der vil waetliche man
###### 300 | ### do gie si zvo dem mvenster | ir volgete manech wip ### do was ovch so gecieret | der kvneginne lip ### daz da hoher wunsche | vil maneger wart verlorn ### si was da ce ovgenweide | vil manegem rechen erchorn
###### 301 | ### vil chvome erbeite sivrit | daz man da gesanch ### er mohte sinen saelden | des immer sagen danch ### daz im div was so waege | di er in hercen trvoch ### ovch was er der scoenen | holt von scvlden genvoch
###### 302 | ### do si chom vz dem mvnster | sam er het e getan ### man bat den degen chvenen | wider zvo zir gan ### alrest begvnd im danchen | div minnechliche meit ### daz er vor manegem helde | so rehte herlichen streit
###### 303 | ### nv lon iv got her sivrit | sprach daz vil scoene chint ### daz ir daz habt verdienet | daz iv die rechen sint ### so holt mit rehten triwen | als ich si hoere iehn ### do begvnder minechliche | an frovn chrimhilden sehn
###### 304 | ### ich sol in immer dienen | also sprach der degn ### vnt en wil min hovbet | nimmer e gelegn ### ih en werbe nach ir willen | sol ich min lebn han ### daz ist nach iwern hvlden | min frov chrimhilt getan
###### 305 | ### inre tagen zwelven | der tage al ieslich ### sah man bi dem degene | di maget loblich ### so si ce hove solde | vor ir vriwenden gan ### der dienst wart dem rechen | dvrch groze liebe getan
###### 306 | ### vrevde vnt wunne | vil groezlichen scal ### sah man aller taegelich | vor gvnthers sal ### darvz vnt ovch darinne | von manegem chvenen man ### oertwin vnt hagene | vil grozer wunder began
###### 307 | ### swes iemen pflegen wolde | des waren si bereit ### mit vollechlicher maze | di helde vil gemeit ### des wurden von den gesten | di rechen wol bechant ### davon so was gezieret | allez gvntheres lant
###### 308 | ### die da wunde lagen | die sah man fver gan ### si wolden chvrzwile | mit dem gesinde han ### schirmen mit den scilden | vnt schiezen manegen scaft ### des hvlfen in genvoge | si heten groezliche chraft
###### 309 | ### in der hohgecite | der wirt der hiez ir pflegn ### mit der besten spise | er hete sich bewegn ### aller slahte scande | di ie kvnech gewan ### man sah in vriwentliche | zvo den sinen gesten gan
###### 310 | ### er sprach ir gvoten rechen | e daz ir sceidet hin ### so nemt ir mine gabe | also stet min sin ### daz ichz immer diene | versmahet iv niht min gvot ### daz wil ich mit iv teilen | des han ich willigen mvot
###### 311 | ### die von tenemarche | di sprachen sa cehant ### e daz wir wider riten | heim in vnser lant ### wir gern staeter svone | des ist vns rechen not ### wir han von iwern degenen | manegen liebn vriwent tot
###### 312 | ### livdegast geheilet | siner wunden was ### der vogt von den sahsen | nach strite wol genas ### eteliche toten | si liezen darn lant ### do gie der kvnec gvnther | da er sivriden vant
###### 313 | ### er sprach zvo dem rechen | nv ratet wie ich tvo ### di vnsern widerwinnen | die wellent riten frvo ### vnd gerent staeter svone | an mich vnt mine man ### nv rata degen sivrit | waz dich des dvnche gvot getan
###### 314 | ### waz mir die herren bieten | daz wil ich dir sagen ### swaz fvnf hvndert moere | goldes moehten getragen ### daz gebn si mir gerne | wold ich si ledech lan ### do sprach der starche sivrit | daz waere vil vbele getan
###### 315 | ### ir svlt si ledechlichen | hinnen lazen varn ### vnt daz di rechen edele | mere wol bewarn ### vientlichez riten | her in iwer lant ### des lat iv gebn sicherheit | hie der beider herrn hant
###### 316 | ### des rates wil ich volgen | damit si giengen dan ### den sinen vianden | wart daz chvnt getan ### ir goldes gerte niemn | daz si da bvten e ### da heime ir lieben vriwenden | was nach den hermveden we
###### 317 | ### manege scilde volle | man dar scazes trvoch ### er teiltes ane wage | den vriwenden sin genvoch ### bi fvnf hvndert marchen | vnt etslichen baz ### gernot der vil chvene | der riet gvnthere daz
###### 318 | ### vrlovp si alle namen | also si wolden dan ### do sah man die geste | fver chrimhilde gan ### vnt ovch da vrovwe vote | div kvneginne saz ### ezn wart nie degen | noch mere gevrlovbet baz
###### 319 | ### die herberge wurden laere | do si von dannen ritten ### noch bestvont da heime | mit herlichn siten ### der kvnech mit sinen magen | vil manech edel man ### di sah man taegeliche | zvo frovwen chrimhilde gan
###### 320 | ### vrlovp do nemen wolde | sivrit der helt gvot ### er trvowete niht erwerben | des er da hete mvot ### der kvnec daz sagen horte | daz er wolde dan ### giselher der ivnge | in von der reise gar gewan
###### 321 | ### war woldet ir nv riten | vil edel sivrit ### belibet bi den rechen | tvot des ich ivch bit ### bi gvnthere dem kvnege | vnt ovch bi sinen man ### hie ist vil scoener frovwen | di sol man ivch gerne sehen lan
###### 322 | ### do sprach der starche sivrit | div ross div lazet stan ### ich wolde hinnen riten | des wil ich ab gan ### vnt tragt ovch hin di schilde | ia wold ich in min lant ### des hat mich her giselher | mit grozen triwen erwant
###### 323 | ### svss beleip der chvene | dvrch vriwende liebe da ### ia waer er in den landen | ninder andrswa ### gewesen also sanfte | davon daz gescach ### daz er nv taegeliche | di scoenen chrimhilden sach
###### 324 | ### dvrch ir vnmazen scoene | der herre da beleip ### mit maneger chvrzewile | man nv di zit vertreip ### wan daz in twang ir minne | div gab im diche not ### darvmbe sit der chvene | lach vil iaemerliche tot

<<< Übersicht <<< vorige Seite nächste Seite >>>